'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var raCore = require('ra-core');
var React = require('react');
var reactAdmin = require('react-admin');
var amplifyMaterialUi = require('amplify-material-ui');
var history = require('history');
var core = require('@material-ui/core');
var reactRouterDom = require('react-router-dom');
var reactRedux = require('react-redux');
var MenuIcon = require('@material-ui/icons/Menu');
var ChevronLeftIcon = require('@material-ui/icons/ChevronLeft');
var createMuiTheme = require('@material-ui/core/styles/createMuiTheme');

function _interopDefault (e) { return e && e.__esModule ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefault(React);
var MenuIcon__default = /*#__PURE__*/_interopDefault(MenuIcon);
var ChevronLeftIcon__default = /*#__PURE__*/_interopDefault(ChevronLeftIcon);
var createMuiTheme__default = /*#__PURE__*/_interopDefault(createMuiTheme);

const useStyles = core.makeStyles(theme => ({
  drawer: {
    [theme.breakpoints.up('sm')]: {
      width: theme.drawerWidth,
      flexShrink: 0
    }
  },
  appBar: {
    marginLeft: theme.drawerWidth,
    [theme.breakpoints.up('sm')]: {
      width: `calc(100% - ${theme.drawerWidth}px)`
    }
  },
  menuButton: {
    marginRight: theme.spacing(2),
    [theme.breakpoints.up('sm')]: {
      display: 'none'
    }
  },
  toolbarIcon: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'flex-end',
    padding: '0 8px',
    ...theme.mixins.toolbar
  },
  drawerPaper: {
    width: theme.drawerWidth
  }
}));
const Header = ({
  title,
  hasDashboard
}) => {
  const classes = useStyles();
  const dispatch = reactRedux.useDispatch();
  const open = reactRedux.useSelector(state => state.admin.ui.sidebarOpen);

  const handleDrawerToggle = () => dispatch(reactAdmin.toggleSidebar());

  const burgerMenu = /*#__PURE__*/React.createElement(core.IconButton, {
    color: "inherit",
    "aria-label": "open drawer",
    edge: "start",
    onClick: handleDrawerToggle,
    className: classes.menuButton
  }, /*#__PURE__*/React.createElement(MenuIcon__default['default'], null));
  const brand = /*#__PURE__*/React.createElement(core.Link, {
    variant: "h6",
    underline: "none",
    color: "inherit",
    component: reactRouterDom.Link,
    to: "/"
  }, title);
  const drawer = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classes.toolbarIcon
  }, /*#__PURE__*/React.createElement(core.Hidden, {
    smUp: true,
    implementation: "css"
  }, /*#__PURE__*/React.createElement(core.IconButton, {
    onClick: handleDrawerToggle
  }, /*#__PURE__*/React.createElement(ChevronLeftIcon__default['default'], null)))), /*#__PURE__*/React.createElement(core.Divider, null), /*#__PURE__*/React.createElement(reactAdmin.Menu, {
    hasDashboard: hasDashboard
  }));
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(amplifyMaterialUi.Greetings, {
    title: brand,
    className: classes.appBar,
    burgerMenu: burgerMenu
  }), /*#__PURE__*/React.createElement("nav", {
    className: classes.drawer,
    "aria-label": "navigation links"
  }, /*#__PURE__*/React.createElement(core.Hidden, {
    smUp: true,
    implementation: "css"
  }, /*#__PURE__*/React.createElement(core.Drawer, {
    variant: "temporary",
    anchor: "left",
    open: open,
    onClose: handleDrawerToggle,
    classes: {
      paper: classes.drawerPaper
    },
    ModalProps: {
      keepMounted: true // Better open performance on mobile.

    }
  }, drawer)), /*#__PURE__*/React.createElement(core.Hidden, {
    xsDown: true,
    implementation: "css"
  }, /*#__PURE__*/React.createElement(core.Drawer, {
    classes: {
      paper: classes.drawerPaper
    },
    variant: "permanent",
    open: open
  }, drawer))));
};

const useStyles$1 = core.makeStyles(theme => ({
  toolbar: theme.mixins.toolbar,
  content: {
    display: 'flex',
    flexDirection: 'column',
    flexGrow: 1,
    backgroundColor: theme.palette.background.default,
    padding: theme.spacing(2),
    [theme.breakpoints.up('sm')]: {
      marginLeft: theme.drawerWidth
    }
  }
}));
const Main = ({
  children
}) => {
  const classes = useStyles$1();
  return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, /*#__PURE__*/React__default['default'].createElement("main", {
    className: classes.content
  }, /*#__PURE__*/React__default['default'].createElement("div", {
    className: classes.toolbar
  }), children));
};

const useStyles$2 = core.makeStyles(() => ({
  root: {
    display: 'flex',
    flexDirection: 'column',
    maxHeight: '100vh'
  }
}));
const Layout = ({
  children,
  dashboard
}) => {
  const classes = useStyles$2();
  return /*#__PURE__*/React__default['default'].createElement("div", {
    className: classes.root
  }, /*#__PURE__*/React__default['default'].createElement(Header, {
    title: "AmplifyReactAdmin",
    hasDashboard: !!dashboard
  }), /*#__PURE__*/React__default['default'].createElement(Main, null, children), /*#__PURE__*/React__default['default'].createElement(reactAdmin.Notification, null));
};

const defaultTheme = createMuiTheme__default['default']({
  drawerWidth: 240
});

const authProvider = () => Promise.resolve();

const Admin = ({
  catchAll = reactAdmin.NotFound,
  children,
  dataProvider,
  history: history$1 = history.createBrowserHistory(),
  layout = Layout,
  loading = amplifyMaterialUi.Loading,
  title = 'AmplifyReactAdmin'
}) => {
  return /*#__PURE__*/React.createElement(amplifyMaterialUi.Authenticator, {
    hide: [amplifyMaterialUi.Greetings],
    hideSignUpLink: true,
    theme: defaultTheme
  }, /*#__PURE__*/React.createElement(amplifyMaterialUi.AuthRoute, {
    validAuthStates: ['signedIn']
  }, () => /*#__PURE__*/React.createElement(reactAdmin.CoreAdminContext, {
    authProvider: authProvider,
    dataProvider: dataProvider,
    history: history$1
  }, /*#__PURE__*/React.createElement(reactAdmin.CoreAdminUI, {
    catchAll: catchAll,
    layout: layout,
    loading: loading,
    loginPage: false,
    title: title
  }, children))));
};

Object.keys(raCore).forEach(function (k) {
  if (k !== 'default') Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () {
      return raCore[k];
    }
  });
});
exports.Admin = Admin;
